==> haskell-optparse-generic-1.5.2-59-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-optparse-generic.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 optparse-generic
version:              1.5.2
visibility:           public
id:                   optparse-generic-1.5.2-fLzfrPkAsJFvQ8ET6dy1L
key:                  optparse-generic-1.5.2-fLzfrPkAsJFvQ8ET6dy1L
license:              BSD-3-Clause
copyright:            2016 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             Auto-generate a command-line parser for your datatype
description:
    This library auto-generates an @optparse-applicative@-compatible
    @Parser@ from any data type that derives the @Generic@ interface.

    See the documentation in "Options.Generic" for an example of how to use
    this library

category:             System
abi:                  2ec61692cfb9541970f048d22545eb9d
exposed:              True
exposed-modules:      Options.Generic
import-dirs:          /usr/lib/ghc-9.4.8/site-local/optparse-generic-1.5.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/optparse-generic-1.5.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/optparse-generic-1.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-optparse-generic
hs-libraries:         HSoptparse-generic-1.5.2-fLzfrPkAsJFvQ8ET6dy1L
depends:
    Only-0.1-2ALIOaFTuVl17VyQ33BnR1 base-4.17.2.1 bytestring-0.11.5.3
    filepath-1.4.2.2
    optparse-applicative-0.18.1.0-HLRS0wxhkSb4kVPN7e82uH text-2.0.2
    time-1.12.2 transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ
    void-0.7.3-H00KtmFLEBuFgBidznP5Pq

haddock-interfaces:
    /usr/share/doc/haskell-optparse-generic/html/optparse-generic.haddock

haddock-html:         /usr/share/doc/haskell-optparse-generic/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-optparse-generic-1.5.2-60-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-optparse-generic.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 optparse-generic
version:              1.5.2
visibility:           public
id:                   optparse-generic-1.5.2-IuZSdan1uRY179qZTVIWMZ
key:                  optparse-generic-1.5.2-IuZSdan1uRY179qZTVIWMZ
license:              BSD-3-Clause
copyright:            2016 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             Auto-generate a command-line parser for your datatype
description:
    This library auto-generates an @optparse-applicative@-compatible
    @Parser@ from any data type that derives the @Generic@ interface.

    See the documentation in "Options.Generic" for an example of how to use
    this library

category:             System
abi:                  0ef291c7d4bd9401dc88c5132993e151
exposed:              True
exposed-modules:      Options.Generic
import-dirs:          /usr/lib/ghc-9.4.8/site-local/optparse-generic-1.5.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/optparse-generic-1.5.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/optparse-generic-1.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-optparse-generic
hs-libraries:         HSoptparse-generic-1.5.2-IuZSdan1uRY179qZTVIWMZ
depends:
    Only-0.1-2ALIOaFTuVl17VyQ33BnR1 base-4.17.2.1 bytestring-0.11.5.3
    filepath-1.4.2.2
    optparse-applicative-0.18.1.0-GDwWCLBUeEeIARGaJHYM6i text-2.0.2
    time-1.12.2 transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ
    void-0.7.3-H00KtmFLEBuFgBidznP5Pq

haddock-interfaces:
    /usr/share/doc/haskell-optparse-generic/html/optparse-generic.haddock

haddock-html:         /usr/share/doc/haskell-optparse-generic/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
